@@ -35,7 +35,7 @@ class RatioWidget : public FractionBaseWidget
 {
 public:
     /** constructor */
-    explicit RatioWidget(QWidget * parent = 0, const Ratio para_ratio = Ratio());
+    explicit RatioWidget(QWidget * parent = nullptr, const Ratio para_ratio = Ratio());
 
     /** destructor */
     ~RatioWidget();
@@ -53,7 +53,7 @@ private:
     /*identify if the fraction will appear in mixed form or not*/
     bool m_questionMixed;
 
-    /** overrideing the paint event of FractionBaseWidget */
+    /** overriding the paint event of FractionBaseWidget */
     void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE;
 };
 
